#! /usr/bin/env python
"""Plots validation of Sarathy skeletal mechanisms for n-butanol ignition delays.
"""
from __future__ import division
import sys
import os.path
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages

home_dir = os.path.join(sys.path[0], '../')
home_dir = os.path.realpath(home_dir)

model = 'Merchant'

figures_dir = os.path.join(home_dir, 'figures')
data_dir = os.path.join(home_dir, 'data', model + '-full-autoignition-validation')

font = {'weight' : 'normal',
        'size' : 16,
        'family' : 'serif',
        'serif' : ['Times New Roman']}
plt.rc('font', **font)

for fuel in ['nbut', 'ibut', 'sbut', 'tbut']:

    for equivalence_ratio in ['0.2', '0.5', '1.0', '1.5', '2.0']:
        plt.clf()

        filename = '{}_{}_phi={}.csv'.format(model, fuel, equivalence_ratio)

        data = np.genfromtxt(os.path.join(data_dir, filename), delimiter=',')
        # contents:
        # 1000/T, Detailed 1atm, Detailed 20atm, Detailed 40atm, DRGEP 1atm, DRGEP 20atm,
        # DRGEPSA 40atm, DRGEPSA 1atm, DRGEPSA 20atm, DRGEPSA 40atm

        # Detailed: 1 atm, 20 atm, 40 atm
        plt.semilogy(data[:,0], data[:,1], marker='o', linestyle='None', color='black',
                     label='Detailed')
        plt.semilogy(data[:,0], data[:,2], marker='o', linestyle='None', color='black')
        plt.semilogy(data[:,0], data[:,3], marker='o', linestyle='None', color='black')

        # DRGEP: 1 atm, 20 atm, 40 atm
        plt.semilogy(data[:,0], np.ma.masked_where(np.isnan(data[:,1]), data[:,4]),
                     linestyle='-', color='blue', label='DRGEP')
        plt.semilogy(data[:,0], np.ma.masked_where(np.isnan(data[:,2]), data[:,5]),
                     linestyle='-', color='blue')
        plt.semilogy(data[:,0], np.ma.masked_where(np.isnan(data[:,3]), data[:,6]),
                     linestyle='-', color='blue')

        # DRGEPSA: 1 atm, 20 atm, 40 atm
        plt.semilogy(data[:,0], np.ma.masked_where(np.isnan(data[:,1]), data[:,7]),
                     linestyle='--', color='red', label='DRGEPSA')
        plt.semilogy(data[:,0], np.ma.masked_where(np.isnan(data[:,2]), data[:,8]),
                     linestyle='--', color='red')
        plt.semilogy(data[:,0], np.ma.masked_where(np.isnan(data[:,3]), data[:,9]),
                     linestyle='--', color='red')

        # find closest values to T = 1000 for pressure labels
        x_loc = 1.0
        idx = np.argmin(np.abs(data[:,0] - x_loc))
        y_loc = data[idx, 1] * 3.0
        plt.text(x_loc, y_loc, '1 atm', fontsize=14, color='black',
                 horizontalalignment='center', verticalalignment='center'
                 )

        x_loc = 1.0
        idx = np.argmin(np.abs(data[:,0] - x_loc))
        y_loc = data[idx, 2] * 2.5
        plt.text(x_loc, y_loc, '20 atm', fontsize=14, color='black',
                 horizontalalignment='center', verticalalignment='center'
                 )

        x_loc = 1.0
        idx = np.argmin(np.abs(data[:,0] - x_loc))
        y_loc = data[idx, 3] / 3.0
        plt.text(x_loc, y_loc, '40 atm', fontsize=14, color='black',
                 horizontalalignment='center', verticalalignment='center'
                 )

        #plt.axis((0.6, 1.5, 1.e-6, 5.e1))
        plt.xlim(0.6, 1.5)

        axis_font = {'fontname':'Times New Roman', 'size':'20'}
        leg_font = {'family':'serif', 'size':'16'}
        plt.legend(loc='lower right', prop=leg_font, numpoints=1)
        plt.xlabel('1000 / T (1/K)', **axis_font)
        plt.ylabel('Ignition delay (s)', **axis_font)
        plt.show()

        # save to file
        pp = PdfPages(os.path.join(figures_dir,
                      '{}_{}_phi={}.pdf'.format(model, fuel, equivalence_ratio))
                      )
        pp.savefig()
        pp.close()
