#! /usr/bin/env python
"""Plots pressure for gasoline and butanol isomers during engine simulation.
"""
from __future__ import print_function, division
import sys
import os.path
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages

home_dir = os.path.join(sys.path[0], '../')
home_dir = os.path.realpath(home_dir)

figures_dir = os.path.join(home_dir, 'figures')
data_dir = os.path.join(home_dir, 'data', 'engine-pressure')

font = {'weight' : 'normal',
        'size' : 16,
        'family' : 'serif',
        'serif' : ['Times New Roman']}
plt.rc('font', **font)
axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}

## gasoline surrogate
# crank angle (deg CA), mass fraction
gasoline = np.genfromtxt(os.path.join(data_dir, 'gasoline-surrogate.txt'), delimiter = ',')

# Sarathy
Sarathy_nbutanol = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol.txt'), delimiter = ',')
Sarathy_isobutanol = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol.txt'), delimiter = ',')
Sarathy_secbutanol = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol.txt'), delimiter = ',')
Sarathy_tertbutanol = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol.txt'), delimiter = ',')

# Merchant
Merchant_nbutanol = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol.txt'), delimiter = ',')
Merchant_isobutanol = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol.txt'), delimiter = ',')
Merchant_secbutanol = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol.txt'), delimiter = ',')
Merchant_tertbutanol = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol.txt'), delimiter = ',')

plt.plot(gasoline[:,0], gasoline[:,1], linestyle='-', color='black', linewidth=2, label='Gasoline surrogate')

plt.plot(Sarathy_nbutanol[:,0], Sarathy_nbutanol[:,1], linestyle='-', color='blue', label=r'$n$-butanol')
plt.plot(Sarathy_isobutanol[:,0], Sarathy_isobutanol[:,1], linestyle='--', color='red', label='isobutanol')
plt.plot(Sarathy_secbutanol[:,0], Sarathy_secbutanol[:,1], linestyle=':', color='green', label=r'$sec$-butanol')
plt.plot(Sarathy_tertbutanol[:,0], Sarathy_tertbutanol[:,1], linestyle='-.', color='magenta', label=r'$tert$-butanol')

plt.plot(Merchant_nbutanol[:,0], Merchant_nbutanol[:,1], linestyle='-', color='blue', marker='.', markevery=3)
plt.plot(Merchant_isobutanol[:,0], Merchant_isobutanol[:,1], linestyle='--', color='red', marker='.', markevery=3)
plt.plot(Merchant_secbutanol[:,0], Merchant_secbutanol[:,1], linestyle=':', color='green', marker='.', markevery=3)
plt.plot(Merchant_tertbutanol[:,0], Merchant_tertbutanol[:,1], linestyle='-.', color='magenta', marker='.', markevery=3)

plt.axis((-21, -6, 19, 133))

plt.annotate('Sarathy\nskeletal', fontsize=16, color='black',
              xytext=(-19, 70), xy=(-13.92, 76),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('Sarathy\nskeletal', fontsize=16, color='black', alpha=0.0,
              xytext=(-19, 70), xy=(-13.352, 70),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('Sarathy\nskeletal', fontsize=16, color='black', alpha=0.0,
              xytext=(-19, 70), xy=(-11.7, 66.143),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('Sarathy\nskeletal', fontsize=16, color='black', alpha=0.0,
              xytext=(-19, 70), xy=(-9.443, 60.857),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

plt.annotate('Merchant\nskeletal', fontsize=16, color='black',
              xytext=(-19, 50), xy=(-15.14, 60.0),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-", color='gray'))
plt.annotate('Merchant\nskeletal', fontsize=16, color='black',
              xytext=(-19, 50), xy=(-14.81, 55.),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-", color='gray'))
plt.annotate('Merchant\nskeletal', fontsize=16, color='black',
              xytext=(-19, 50), xy=(-9.321, 49.859),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-", color='gray'))
plt.annotate('Merchant\nskeletal', fontsize=16, color='black',
              xytext=(-19, 50), xy=(-8.65, 43.8),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-", color='gray'))


axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='upper left', prop=leg_font, numpoints=1)

plt.xlabel('Crank angle ($^\circ$CA)', **axis_font)
plt.ylabel('Pressure (atm)', **axis_font)

plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'fuel_engine_pressure.pdf'))
pp.savefig()
pp.close()
