#! /usr/bin/env python
"""Plots comparison of isobutanol mass fraction for different reaction formulations.
"""
from __future__ import print_function, division
import sys
import os.path
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages

home_dir = os.path.join(sys.path[0], '../')
home_dir = os.path.realpath(home_dir)

figures_dir = os.path.join(home_dir, 'figures')
data_dir = os.path.join(home_dir, 'data')

font = {'weight' : 'normal',
        'size' : 16,
        'family' : 'serif',
        'serif' : ['Times New Roman']}
plt.rc('font', **font)
axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}

# time (s), duplicate, single, 1st, 2nd
data = np.genfromtxt(os.path.join(data_dir, 'plog-half-life-isobutanol.txt'), delimiter=',')

# find half-life location for each
half_dup = np.interp(0.5, data[:,1][::-1], data[:,0][::-1])
half_single = np.interp(0.5, data[:,2][::-1], data[:,0][::-1])
half_1st = np.interp(0.5, data[:,3][::-1], data[:,0][::-1])
half_2nd = np.interp(0.5, data[:,4][::-1], data[:,0][::-1])

plt.plot(data[:,0], data[:,1], linestyle='-', color='black',
         label='Duplicate-reaction', linewidth=2
         )
plt.plot([half_dup, half_dup], [0, 0.5], linestyle='-', color='black', linewidth=2)

plt.plot(data[:,0], data[:,2], linestyle='-', color='green',
         label='Multiple-expression'
         )
plt.plot([half_single, half_single], [0, 0.5], linestyle='-', color='green')

plt.plot(data[:,0], data[:,3], linestyle='--', color='red',
         label='First reaction'
         )
plt.plot([half_1st, half_1st], [0, 0.5], linestyle='--', color='red')

plt.plot(data[:,0], data[:,4], linestyle='-.', color='blue',
         label='Second reaction'
         )
plt.plot([half_2nd, half_2nd], [0, 0.5], linestyle='-.', color='blue')

print('Half life times for each reaction formulation: ')
print('Duplicate-reaction: {:.2f}'.format(half_dup))
print('Multiple-expression: {:.2f}'.format(half_single))
print('1st: {:.2f}'.format(half_1st))
print('2nd: {:.2f}'.format(half_2nd))

plt.axis((0., 200., 0., 1.))
plt.legend(loc='upper right', prop=leg_font, numpoints=1)
plt.xlabel('Time (s)', **axis_font)
plt.ylabel('Mass fraction of isobutanol', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'isobutanol_plog_halflife.pdf'))
pp.savefig()
pp.close()
